yakumo.neutron.v2.security_group

Package yakumo :: Package neutron :: Package v2 :: Module security_group |
[hide private]
[frames] | no frames]

# Source Code for Module yakumo.neutron.v2.security_group

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #    Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #    not use this file except in compliance with the License. You may obtain
     6  #    a copy of the License at
     7  #
     8  #         http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #    Unless required by applicable law or agreed to in writing, software
    11  #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #    License for the specific language governing permissions and limitations
    14  #    under the License.
    15
    16  """
    17  Resource class and its manager for security groups in Networking V2 API
    18  """
    19
    20  from yakumo import base
    21  from yakumo.constant import UNDEF
    22  from yakumo import mapper
    23  from . import security_group_rule
    24
    25
    26  ATTRIBUTE_MAPPING = [
    27      ('id', 'id', mapper.Noop),
    28      ('name', 'name', mapper.Noop),
    29      ('description', 'description', mapper.Noop),
    30      ('project', 'tenant_id', mapper.Resource('project')),
    31  ]
    32
    33
    34 -class Resource(base.Resource):
    35      """Resource class for security groups in Networking V2 API"""
    36
    37      _sub_manager_list = {
    38          'rules': security_group_rule.Manager
    39      }
    40
    41
    42 -class Manager(base.Manager):
    43      """Manager class for security groups in Networking V2 API"""
    44
    45      resource_class = Resource
    46      service_type = 'network'
    47      _attr_mapping = ATTRIBUTE_MAPPING
    48      _hidden_methods = ["update"]
    49      _json_resource_key = 'security_group'
    50      _json_resources_key = 'security_groups'
    51      _url_resource_path = '/v2.0/security-groups'
    52
    53 -    def create(self, name=UNDEF, description=UNDEF, project=UNDEF):
    54          """
    55          Create a security group
    56
    57          @keyword name: Security group name
    58          @type name: str
    59          @keyword description: Description
    60          @type description: str
    61          @keyword project: Project
    62          @type project: yakumo.project.Resource
    63          @return: Created security group
    64          @rtype: yakumo.neutron.v2.security_group.Resource
    65          """
    66          return super(Manager, self).create(name=name,
    67                                             description=description,
    68                                             project=project)
    69